@@ -633,8 +633,11 @@ class UnixRegistry:
         return values    
                 
     def SaveValues(self, values):
+        # update old values
+        old_values=self.LoadValues()
+        old_values.update(values)
         data=""
-        for k, v in values.iteritems():
+        for k, v in old_values.iteritems():
             data+='%s=%s\n' % (k, str(v))
         filedata=open(self.filename, "w")
         filedata.write(data)
