@@ -346,8 +346,13 @@ class ESXMon(Archiver):
         status+='end_epoch=%d\r\n' % end
 
         # do I need to send an email or alert MagiKmon ?
-        prev_values, magikmon={}, job['magikmon']
-        if self.mail_when!='always' or magikmon:
+        prev_values, magikmon, registry={}, job['magikmon'], None
+
+        if self.mail_when in ('never', ):
+            job['mail']=False # sorry for cheating
+            log.info('never send any email')
+        
+        if not self.mail_when in ('always', 'never') or magikmon:
             try:
                 import hashlib
                 md5sum=hashlib.md5(data).hexdigest()
@@ -363,25 +368,36 @@ class ESXMon(Archiver):
                 
             prev_values=registry.LoadValues()
             registry.SaveValues(dict(status=backup_status, md5sum=md5sum, last=int(time.time())))
-            registry.Close()
-            
-            changed_status=prev_values.get('status')!=backup_status
-            changed_md5sum=prev_values.get('md5sum')!=md5sum
-            expired=isinstance(self.mail_when, int) and (time.time()-int(prev_values.get('last', 0)))>self.mail_when
-            log.debug('status changed=%r   report changed=%r   time expired=%r', changed_status, changed_md5sum, expired)
-            if self.mail_when!='never' and (self.mail_when=='always' or expired or (isinstance(self.mail_when, int) and (changed_status or changed_md5sum)) or (self.mail_when=='change' and (changed_status or changed_md5sum)) or (self.mail_when=='status' and changed_status)):
-                # send an email
-                pass
-            else:
-                # don't send the email ! sorry for cheating
-                job['mail']=False
-                log.info('don\'t send any email because the status has not changed')
+
+            # check if I need to send an email
+            if not self.mail_when in ('always', 'never'):
+                changed_status=prev_values.get('mail.status', '<UNK>')!=backup_status
+                changed_md5sum=prev_values.get('mail.md5sum', '<md5>')!=md5sum
+                expired=isinstance(self.mail_when, int) and (time.time()-int(prev_values.get('mail.last', 0)))>self.mail_when
+                log.debug('mail status changed=%r   report changed=%r   time expired=%r', changed_status, changed_md5sum, expired)
+                if self.mail_when=='always' or expired or (isinstance(self.mail_when, int) and (changed_status or changed_md5sum)) or (self.mail_when=='change' and (changed_status or changed_md5sum)) or (self.mail_when=='status' and changed_status):
+                    # send an email
+                    registry.SaveValues({'mail.status':backup_status, 'mail.md5sum':md5sum, 'mail.last':int(time.time())})
+                else:
+                    # don't send the email ! 
+                    job['mail']=False # sorry for cheating
+                    log.info('don\'t send any email because the status has not changed')
+
+            # update MagiKmon, no more then once per hour except when something changed !
+            if magikmon:
                 
-            # update MagiKmon, no more then once always hour except when something changed !
-            if magikmon and not changed_status and not changed_md5sum and time.time()-int(prev_values.get('last', 0))<3300:
-                log.info('don\'t update MagiKmon status')
-                magikmon=None
-        
+                changed_status=prev_values.get('magikmon.status', '<UNK>')!=backup_status
+                changed_md5sum=prev_values.get('magikmon.md5sum', '<md5>')!=md5sum
+                expired=(time.time()-int(prev_values.get('magikmon.last', 0)))>3300
+                # log.debug('magikmon status %r %r', prev_values.get('magikmon.status', '<UNK>'), backup_status)
+                # log.debug('magikmon md5sum %r %r', prev_values.get('magikmon.md5sum', '<md5>'), md5sum)
+                log.debug('magikmon status changed=%r   report changed=%r   time expired=%r', changed_status, changed_md5sum, expired)
+                if changed_status or changed_md5sum or expired:
+                    pass # send
+                else:
+                    log.info('don\'t update MagiKmon status this time')
+                    magikmon=None
+
         if magikmon:
             data=urllib.urlencode(dict(status=backup_status, payload=data))
             try:
@@ -394,5 +410,9 @@ class ESXMon(Archiver):
                 log.exception('error updating MagiKmon status: %s', e)
             else:
                 log.debug('MagiKmon updated: %s', magikmon)
+                registry.SaveValues({'magikmon.status':backup_status, 'magikmon.md5sum':md5sum, 'magikmon.last':int(time.time())})
+        
+        if registry:
+            registry.Close()
         
         return backup_status, status, attachments
