@@ -11,6 +11,7 @@ import win32com.shell
 from win32com.shell import shell, shellcon
 
 from archiver import *
+from windows import WindowsErrorDecode, windows_list_dir
 
 import cron
 
@@ -49,6 +50,7 @@ class NTBackup(Archiver):
         self.restricted=None
         self.logdir=None
         self.snap=None
+        self.options=[]
         
         self.type=None
         self.target=None
@@ -74,7 +76,6 @@ class NTBackup(Archiver):
         #
         
         self.selection=job.get('selection', None)
-        print self.selection, self.selection.startswith('@'), os.path.isfile(self.selection), self.selection[-4:].lower()
         if not self.selection:
             errors['selection']='option mandatory'
         else:
@@ -140,7 +141,16 @@ class NTBackup(Archiver):
                         try:
                             os.makedirs(self.target_dir)
                         except WindowsError, e:
-                            errors['destination']='directory not found: %s (%s)' % (self.target_dir, e)
+                            errors['destination']='directory not found: %s (%s)' % (self.target_dir, WindowsErrorDecode(e))
+
+        options=job.get('options', '')
+        try:
+            options=quoted_string_list(options)
+        except ValueError:
+            errors['options']='not a valid quoted string list'
+        else:
+            self.options=options
+
         
         extra+='ntbackup=%s\n' % self.program_exe
 
@@ -158,6 +168,7 @@ class NTBackup(Archiver):
                     self.cmd_args.append('/SNAP:'+self.onoff[self.snap])
                 
                 self.cmd_args.append('/l:s') # logging [s]ummary
+                self.cmd_args.extend(self.options)
                 # '/hc:off'
             
                 extra+='cmdline=%s\n' % '  '.join(self.cmd_args)
@@ -181,6 +192,7 @@ class NTBackup(Archiver):
             log.error('command: %r', self.cmd_args)
             if self.is64bits: 
                 log.error('On 64bits system you must use the 64bits trick, check the doc for more...')
+            raise
 
         # choose the oldest log file
         logfile, last=None, 0
@@ -216,8 +228,8 @@ class NTBackup(Archiver):
         try:
             stat=os.stat(self.target)
         except Exception, e:
-            log.error('checking target file: %s', e)
-            status+='target_stat_error=%s\r\n' % e
+            log.error('checking target file: %s', WindowsErrorDecode(e))
+            status+='target_stat_error=%s\r\n' % WindowsErrorDecode(e)
         else:
             status+='target_size=%d\r\n' % stat.st_size
             status+='target_mtime_epoch=%d\r\n' % stat.st_mtime
@@ -227,27 +239,27 @@ class NTBackup(Archiver):
         dir_out=None
         try:
             total_free_bytes=free_space(self.target_dir, log)
-            dir_out, _total_size=list_dir(self.target_dir, log)        
+            dir_out, _total_size=windows_list_dir(self.target_dir, log)        
         except Exception, e:
-            log.error('checking target directory: %s', e)
-            status+='target_directory_error=%s\r\n' % e
+            log.error('checking target directory: %s', WindowsErrorDecode(e))
+            status+='target_directory_error=%s\r\n' % WindowsErrorDecode(e)
         else:
             status+='target_free_space=%d\r\n' % total_free_bytes
 
         status+='cmdline=%s\r\n' % ' '.join(self.cmd_args)
 
-        attachements=[ # the type, subtype and coding is not used
+        attachments=[ # the type, subtype and coding is not used
                        ('log.txt', logfile, None, 'text', 'plain', 'utf-16'),
                        ('evlog.txt', None, ev_out.encode('utf-8'), 'text', 'plain', 'utf-8'),
                     ]
 
         if dir_out:
-            attachements.append(('dir.txt', None, dir_out.encode('utf-8'), 'text', 'plain', 'utf-8'))
+            attachments.append(('dir.txt', None, dir_out.encode('utf-8'), 'text', 'plain', 'utf-8'))
         if self.selection.startswith('@'):
-            attachements.append(('selection.bks', self.selection[1:], None, 'text', 'plain', 'utf-16'))
+            attachments.append(('selection.bks', self.selection[1:], None, 'text', 'plain', 'utf-16'))
         if std_out:
-            attachements.append(('stdout.txt', None, std_out, 'text', 'plain', manager.console_encoding))
+            attachments.append(('stdout.txt', None, std_out, 'text', 'plain', manager.console_encoding))
         if std_err:
-            attachements.append(('stderr.txt', None, std_err, 'text', 'plain', manager.console_encoding))
-        
-        return ev_status, status, attachements
+            attachments.append(('stderr.txt', None, std_err, 'text', 'plain', manager.console_encoding))
+
+        return ev_status, status, attachments
